-- MIX script pro S6R a S8R přepínání stabilizovaných režimů
-- testováno na S6R
-- odkazuje se na zvuky dodané k rádiím zakoupeným u RCStudio
--
-- vymyšlené pro ovládání třemi 3-polohovými přepínači (3 letové režimy)
--
-- přepínače mají 3 polohy značené jako:
--
--      ^     -100%
--      -        0%
--      v      100%
--
--   0 musí být +- treshold (10%), zbytek jsou hodnoty + a -
--
-- "zadání"
--  Tři přepínače na ovládání (např. SC na režimy, SB na základní stabilizaci, SC na extra režimy):
--   - SC režim letu ^ a - = neacro, v = acro
--   - SA "crazy" režimy - = nic, ^ = svíčka, v = nožák
--   - SB std stabilizace  - = nic, ^ = std stabilizace (vypínač větru), v = autolevel
-- "crazy" režimy fungují pouze v režimu "acro" a pokud není vybraná std stabilizace nebo autolevel.

local	input =	{
    { "Flight Mod", SOURCE },
    { "Basic Stab", SOURCE },
    { "Adv.  Stab", SOURCE }
}

local output = { "Ch10", "Ch11" }

-- režimy stabilizace vždy dvojice ch10 a ch11, hodnoty -1024, 0, 1024 pro polohy low, mid, high; resp ^, -, v
local X = 1024 -- velikost hodnoty odeslané na řídící kanál
local stab = {
    { ch10=0, ch11=0, wav="bezstab.wav" }, -- 1 druhá hodnota je libovolná
    { ch10=X, ch11=0, wav="SAS.wav" },     -- 2
    { ch10=X, ch11=X, wav="AL.wav" },      -- 3
    { ch10=X, ch11=-X, wav="svicka.wav" }, -- 4 na vrtuli
    { ch10=-X, ch11=0, wav="nozak.wav" }   -- 5 nozovy let
}

local lastStab = 0;
local newStab = 0;

local treshold = 103; -- pro určení polohy přepínače

local	function	init_func() 
end

local	function	run_func(flMod, basMod, advMod) 
    newStab = 1
    if ( basMod < -treshold ) -- basic stab
    then
        newStab = 2
    elseif ( basMod > treshold ) -- autolevel
    then 
        newStab = 3
    elseif ( flMod > treshold ) -- acro rezim
    then
        if ( advMod < -treshold ) -- hower; svicka
        then
            newStab = 4
        elseif ( advMod > treshold ) -- edge; nozak
        then
            newStab = 5
        end
    end
    if (newStab ~= lastStab) 
    then
        lastStab = newStab
        playFile(stab[newStab].wav)
    end
    return stab[newStab].ch10, stab[newStab].ch11
end
return { input=input, output=output, run=run_func, init=init_func }
